==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppPublicCertificateSlot.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [WebAppPublicCertificateSlot].
 */
@PulumiTagMarker
public class WebAppPublicCertificateSlotResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WebAppPublicCertificateSlotArgs = WebAppPublicCertificateSlotArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WebAppPublicCertificateSlotArgsBuilder.() -> Unit) {
        val builder = WebAppPublicCertificateSlotArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): WebAppPublicCertificateSlot {
        val builtJavaResource =
            com.pulumi.azurenative.web.WebAppPublicCertificateSlot(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WebAppPublicCertificateSlot(builtJavaResource)
    }
}

/**
 * Public certificate object
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2020-10-01, 2023-01-01.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppPublicCertificateSlot myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/slots/{slot}/publicCertificates/{publicCertificateName}
 * ```
 */
public class WebAppPublicCertificateSlot internal constructor(
    override val javaResource: com.pulumi.azurenative.web.WebAppPublicCertificateSlot,
) : KotlinCustomResource(javaResource, WebAppPublicCertificateSlotMapper) {
    /**
     * Public Certificate byte array
     */
    public val blob: Output<String>?
        get() = javaResource.blob().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Kind of resource.
     */
    public val kind: Output<String>?
        get() = javaResource.kind().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Resource Name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Public Certificate Location
     */
    public val publicCertificateLocation: Output<String>?
        get() = javaResource.publicCertificateLocation().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Certificate Thumbprint
     */
    public val thumbprint: Output<String>
        get() = javaResource.thumbprint().applyValue({ args0 -> args0 })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WebAppPublicCertificateSlotMapper : ResourceMapper<WebAppPublicCertificateSlot> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.web.WebAppPublicCertificateSlot::class == javaResource::class

    override fun map(javaResource: Resource): WebAppPublicCertificateSlot =
        WebAppPublicCertificateSlot(
            javaResource as
                com.pulumi.azurenative.web.WebAppPublicCertificateSlot,
        )
}

/**
 * @see [WebAppPublicCertificateSlot].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WebAppPublicCertificateSlot].
 */
public suspend fun webAppPublicCertificateSlot(
    name: String,
    block: suspend WebAppPublicCertificateSlotResourceBuilder.() -> Unit,
):
    WebAppPublicCertificateSlot {
    val builder = WebAppPublicCertificateSlotResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WebAppPublicCertificateSlot].
 * @param name The _unique_ name of the resulting resource.
 */
public fun webAppPublicCertificateSlot(name: String): WebAppPublicCertificateSlot {
    val builder = WebAppPublicCertificateSlotResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppPublicCertificateSlot.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [WebAppPublicCertificateSlot].
 */
@PulumiTagMarker
public class WebAppPublicCertificateSlotResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WebAppPublicCertificateSlotArgs = WebAppPublicCertificateSlotArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WebAppPublicCertificateSlotArgsBuilder.() -> Unit) {
        val builder = WebAppPublicCertificateSlotArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): WebAppPublicCertificateSlot {
        val builtJavaResource =
            com.pulumi.azurenative.web.WebAppPublicCertificateSlot(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WebAppPublicCertificateSlot(builtJavaResource)
    }
}

/**
 * Public certificate object
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2020-10-01, 2023-01-01.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppPublicCertificateSlot myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/slots/{slot}/publicCertificates/{publicCertificateName}
 * ```
 */
public class WebAppPublicCertificateSlot internal constructor(
    override val javaResource: com.pulumi.azurenative.web.WebAppPublicCertificateSlot,
) : KotlinCustomResource(javaResource, WebAppPublicCertificateSlotMapper) {
    /**
     * Public Certificate byte array
     */
    public val blob: Output<String>?
        get() = javaResource.blob().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Kind of resource.
     */
    public val kind: Output<String>?
        get() = javaResource.kind().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Resource Name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Public Certificate Location
     */
    public val publicCertificateLocation: Output<String>?
        get() = javaResource.publicCertificateLocation().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Certificate Thumbprint
     */
    public val thumbprint: Output<String>
        get() = javaResource.thumbprint().applyValue({ args0 -> args0 })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WebAppPublicCertificateSlotMapper : ResourceMapper<WebAppPublicCertificateSlot> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.web.WebAppPublicCertificateSlot::class == javaResource::class

    override fun map(javaResource: Resource): WebAppPublicCertificateSlot =
        WebAppPublicCertificateSlot(
            javaResource as
                com.pulumi.azurenative.web.WebAppPublicCertificateSlot,
        )
}

/**
 * @see [WebAppPublicCertificateSlot].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WebAppPublicCertificateSlot].
 */
public suspend fun webAppPublicCertificateSlot(
    name: String,
    block: suspend WebAppPublicCertificateSlotResourceBuilder.() -> Unit,
):
    WebAppPublicCertificateSlot {
    val builder = WebAppPublicCertificateSlotResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WebAppPublicCertificateSlot].
 * @param name The _unique_ name of the resulting resource.
 */
public fun webAppPublicCertificateSlot(name: String): WebAppPublicCertificateSlot {
    val builder = WebAppPublicCertificateSlotResourceBuilder()
    builder.name(name)
    return builder.build()
}
